# PyUtra
This is a python library that is meant to try to be jack of all trades.\
Also the typo is intentional, pyultra was banned by pypi.
## Current Features
JSON Config System\
Colorful Text\
Small Debugging System\
Discord Webhook Library\
Pastebin Library\
Network/Internet Library